@@ -1,9 +1,14 @@
 """Tests for the different themes we claim to support."""
 
-import sys
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import pytest
 
+if TYPE_CHECKING:
+    from mkdocstrings.handlers.python import PythonHandler
+
 
 @pytest.mark.parametrize(
     "plugin",
@@ -15,7 +20,7 @@ import pytest
     indirect=["plugin"],
 )
 @pytest.mark.parametrize(
-    "module",
+    "identifier",
     [
         "mkdocstrings.extension",
         "mkdocstrings.inventory",
@@ -26,15 +31,13 @@ import pytest
         "mkdocstrings_handlers.python",
     ],
 )
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="material is not installed on Python 3.6")
-def test_render_themes_templates_python(module, plugin):
+def test_render_themes_templates_python(identifier: str, handler: PythonHandler) -> None:
     """Test rendering of a given theme's templates.
 
     Parameters:
-        module: Parametrized argument.
-        plugin: Pytest fixture: [tests.conftest.fixture_plugin][].
+        identifier: Parametrized identifier.
+        handler: Python handler (fixture).
     """
-    handler = plugin.handlers.get_handler("python")
-    handler._update_env(plugin.md, plugin.handlers._config)  # noqa: WPS437
-    data = handler.collect(module, {})
-    handler.render(data, {})
+    options = handler.get_options({})
+    data = handler.collect(identifier, options)
+    handler.render(data, options)
